@@ -1,4 +1,4 @@
-use crate::ByteFormat;
+use dua::ByteFormat;
 use std::borrow::Borrow;
 use tui::{
     buffer::Buffer,
@@ -14,6 +14,8 @@ pub struct Footer;
 pub struct FooterProps {
     pub total_bytes: Option<u128>,
     pub entries_traversed: u64,
+    pub traversal_start: std::time::Instant,
+    pub elapsed: Option<std::time::Duration>,
     pub format: ByteFormat,
     pub message: Option<String>,
 }
@@ -23,18 +25,31 @@ impl Footer {
         let FooterProps {
             total_bytes,
             entries_traversed,
+            elapsed,
+            traversal_start,
             format,
             message,
         } = props.borrow();
 
         let spans = vec![
             Span::from(format!(
-                " Total disk usage: {}  Entries: {}   ",
+                " Total disk usage: {}  Entries: {} {progress}  ",
                 match total_bytes {
                     Some(b) => format!("{}", format.display(*b)),
                     None => "-".to_owned(),
                 },
                 entries_traversed,
+                progress = match elapsed {
+                    Some(elapsed) => format!("in {:.02}s", elapsed.as_secs_f32()),
+                    None => {
+                        let elapsed = traversal_start.elapsed();
+                        format!(
+                            "in {:.0}s ({:.0}/s)",
+                            elapsed.as_secs_f32(),
+                            *entries_traversed as f32 / elapsed.as_secs_f32()
+                        )
+                    }
+                }
             ))
             .into(),
             message.as_ref().map(|m| {
